@@ -131,7 +131,7 @@ class APIChecks(APIPrivateView, APIGet, DepositReadMixin):
         return True, None
 
     def process_get(
-        self, req: Request, collection_name: str, deposit_id: int
+        self, req: Request, collection_name: str, deposit: Deposit
     ) -> Tuple[int, Dict, str]:
         """Build a unique tarball from the multiple received and stream that
            content to the client.
@@ -139,13 +139,12 @@ class APIChecks(APIPrivateView, APIGet, DepositReadMixin):
         Args:
             req: Client request
             collection_name: Collection owning the deposit
-            deposit_id: Deposit concerned by the reading
+            deposit: Deposit concerned by the reading
 
         Returns:
             Tuple status, stream of content, content-type
 
         """
-        deposit = Deposit.objects.get(pk=deposit_id)
         metadata, _ = self._metadata_get(deposit)
         problems: Dict = {}
         # will check each deposit's associated request (both of type
