@@ -16,12 +16,7 @@ import yaml
 
 from swh.deposit.api.checks import check_metadata
 from swh.deposit.cli import deposit as cli
-from swh.deposit.cli.client import (
-    InputError,
-    _collection,
-    _url,
-    generate_metadata,
-)
+from swh.deposit.cli.client import InputError, _collection, _url, generate_metadata
 from swh.deposit.client import MaintenanceError, PublicApiDepositClient
 from swh.deposit.parsers import parse_xml
 from swh.model.exceptions import ValidationError
@@ -101,6 +96,37 @@ def test_cli_collection_ko_because_downtime():
         _collection(mock_client)
 
 
+def test_cli_upload_conflictual_flags(
+    datadir, requests_mock_datadir, cli_runner, atom_dataset, tmp_path,
+):
+    """Post metadata-only deposit through cli with invalid swhid raises
+
+    """
+    api_url_basename = "deposit.test.metadataonly"
+    metadata = atom_dataset["entry-data-minimal"]
+    metadata_path = os.path.join(tmp_path, "entry-data-minimal.xml")
+    with open(metadata_path, "w") as f:
+        f.write(metadata)
+
+    with pytest.raises(InputError, match="both with different values"):
+        # fmt: off
+        cli_runner.invoke(
+            cli,
+            [
+                "upload",
+                "--url", f"https://{api_url_basename}/1",
+                "--username", TEST_USER["username"],
+                "--password", TEST_USER["password"],
+                "--metadata", metadata_path,
+                "--slug", "some-slug",  # deprecated flag
+                "--create-origin", "some-other-slug",  # conflictual value, so raise
+                "--format", "json",
+            ],
+            catch_exceptions=False,
+        )
+        # fmt: on
+
+
 def test_cli_deposit_with_server_down_for_maintenance(
     sample_archive, caplog, client_mock_api_down, slug, patched_tmp_path, cli_runner
 ):
@@ -139,7 +165,11 @@ def test_cli_client_generate_metadata_ok(slug):
 
     """
     actual_metadata_xml = generate_metadata(
-        "deposit-client", "project-name", "external-id", authors=["some", "authors"]
+        "deposit-client",
+        "project-name",
+        authors=["some", "authors"],
+        external_id="external-id",
+        create_origin="origin-url",
     )
 
     actual_metadata = dict(parse_xml(actual_metadata_xml))
@@ -152,6 +182,10 @@ def test_cli_client_generate_metadata_ok(slug):
         OrderedDict([("codemeta:name", "some")]),
         OrderedDict([("codemeta:name", "authors")]),
     ]
+    assert (
+        actual_metadata["swh:deposit"]["swh:create_origin"]["swh:origin"]["@url"]
+        == "origin-url"
+    )
 
     checks_ok, detail = check_metadata(actual_metadata)
 
@@ -159,8 +193,34 @@ def test_cli_client_generate_metadata_ok(slug):
     assert detail is None
 
 
-def test_cli_single_minimal_deposit(
-    sample_archive, slug, patched_tmp_path, requests_mock_datadir, cli_runner
+def test_cli_client_generate_metadata_ok2(slug):
+    """Generated metadata is well formed and pass service side metadata checks
+
+    """
+    actual_metadata_xml = generate_metadata(
+        "deposit-client", "project-name", authors=["some", "authors"],
+    )
+
+    actual_metadata = dict(parse_xml(actual_metadata_xml))
+    assert actual_metadata["atom:author"] == "deposit-client"
+    assert actual_metadata["atom:title"] == "project-name"
+    assert actual_metadata["atom:updated"] is not None
+    assert actual_metadata["codemeta:name"] == "project-name"
+    assert actual_metadata["codemeta:author"] == [
+        OrderedDict([("codemeta:name", "some")]),
+        OrderedDict([("codemeta:name", "authors")]),
+    ]
+    assert actual_metadata.get("codemeta:identifier") is None
+    assert actual_metadata.get("swh:deposit") is None
+
+    checks_ok, detail = check_metadata(actual_metadata)
+
+    assert checks_ok is True
+    assert detail is None
+
+
+def test_cli_single_minimal_deposit_with_slug(
+    sample_archive, slug, patched_tmp_path, requests_mock_datadir, cli_runner, caplog,
 ):
     """ This ensure a single deposit upload through the cli is fine, cf.
     https://docs.softwareheritage.org/devel/swh-deposit/getting-started.html#single-deposit
@@ -203,6 +263,72 @@ def test_cli_single_minimal_deposit(
             [("codemeta:name", "Jane Doe")]
         )
 
+    count_warnings = 0
+    for (_, log_level, _) in caplog.record_tuples:
+        count_warnings += 1 if log_level == logging.WARNING else 0
+
+    assert (
+        count_warnings == 1
+    ), "We should have 1 warning as we are using slug instead of create_origin"
+
+
+def test_cli_single_minimal_deposit_with_create_origin(
+    sample_archive, slug, patched_tmp_path, requests_mock_datadir, cli_runner, caplog,
+):
+    """ This ensure a single deposit upload through the cli is fine, cf.
+    https://docs.softwareheritage.org/devel/swh-deposit/getting-started.html#single-deposit
+    """  # noqa
+
+    metadata_path = os.path.join(patched_tmp_path, "metadata.xml")
+    origin = slug
+
+    # fmt: off
+    result = cli_runner.invoke(
+        cli,
+        [
+            "upload",
+            "--url", "https://deposit.swh.test/1",
+            "--username", TEST_USER["username"],
+            "--password", TEST_USER["password"],
+            "--name", "test-project",
+            "--archive", sample_archive["path"],
+            "--author", "Jane Doe",
+            "--create-origin", origin,
+            "--format", "json",
+        ],
+    )
+    # fmt: on
+
+    assert result.exit_code == 0, result.output
+    assert json.loads(result.output) == {
+        "deposit_id": "615",
+        "deposit_status": "partial",
+        "deposit_status_detail": None,
+        "deposit_date": "Oct. 8, 2020, 4:57 p.m.",
+    }
+
+    with open(metadata_path) as fd:
+        actual_metadata = dict(parse_xml(fd.read()))
+        assert actual_metadata["atom:author"] == TEST_USER["username"]
+        assert actual_metadata["codemeta:name"] == "test-project"
+        assert actual_metadata["atom:title"] == "test-project"
+        assert actual_metadata["atom:updated"] is not None
+        assert (
+            actual_metadata["swh:deposit"]["swh:create_origin"]["swh:origin"]["@url"]
+            == origin
+        )
+        assert actual_metadata["codemeta:author"] == OrderedDict(
+            [("codemeta:name", "Jane Doe")]
+        )
+
+    count_warnings = 0
+    for (_, log_level, _) in caplog.record_tuples:
+        count_warnings += 1 if log_level == logging.WARNING else 0
+
+    assert (
+        count_warnings == 0
+    ), "We should have no warning as we are using create_origin"
+
 
 def test_cli_validation_metadata(
     sample_archive, caplog, patched_tmp_path, cli_runner, slug
@@ -310,8 +436,9 @@ def test_cli_validation_metadata(
             logging.ERROR,
             (
                 "Problem during parsing options: "
-                "Using --metadata flag is incompatible with both "
-                "--author and --name (Those are used to generate one metadata file)."
+                "Using --metadata flag is incompatible with --author "
+                "and --name and --create-origin (those are used to generate "
+                "one metadata file)."
             ),
         )
         assert expected_error_log_record in caplog.record_tuples
@@ -747,3 +874,44 @@ def test_cli_metadata_only_deposit_no_swhid(
             catch_exceptions=False,
         )
         # fmt: on
+
+
+@pytest.mark.parametrize(
+    "metadata_entry_key", ["entry-data-with-add-to-origin", "entry-only-create-origin"]
+)
+def test_cli_deposit_warning_missing_origin(
+    sample_archive,
+    metadata_entry_key,
+    tmp_path,
+    atom_dataset,
+    caplog,
+    cli_runner,
+    requests_mock_datadir,
+):
+    """Deposit cli should log warning when the provided metadata xml is missing origins
+
+    """
+    # For the next deposit, no warning should be logged as either <swh:create_origin> or
+    # <swh:origin_to_add> are provided
+
+    metadata_raw = atom_dataset[metadata_entry_key] % "some-url"
+    metadata_path = os.path.join(tmp_path, "metadata-with-origin-tag-to-deposit.xml")
+    with open(metadata_path, "w") as f:
+        f.write(metadata_raw)
+
+    # fmt: off
+    cli_runner.invoke(
+        cli,
+        [
+            "upload",
+            "--url", "https://deposit.swh.test/1",
+            "--username", TEST_USER["username"],
+            "--password", TEST_USER["password"],
+            "--metadata", metadata_path,
+        ],
+    )
+    # fmt: on
+
+    for (_, log_level, _) in caplog.record_tuples:
+        # all messages are info or below messages so everything is fine
+        assert log_level < logging.WARNING
